@@ -650,12 +650,7 @@ namespace Oxygen
             if( !page ) continue;
 
             GtkWidget* label( gtk_notebook_get_tab_label( notebook, page ) );
-
-            #if GTK_CHECK_VERSION(2, 20, 0)
             if( label && !gtk_widget_get_mapped( label ) ) return true;
-            #else
-            if( label && !GTK_WIDGET_MAPPED( label ) ) return true;
-            #endif
         }
 
         return false;
